==> xoonips-2.00a.tar.gz: xoonips-2.00a/xoonips/admin/index.php <==
<?php
//  $Revision: 1.6 $                                                                  //
//  --------------------------------------------------------------------------  //
//  XooNIps Xoops modules for Neuroinformatics Platforms                        //
//  Copyright (C) 2005 RIKEN, Japan. All rights reserved.                       //
//  http://sourceforge.jp/projects/xoonips/                                     //
//  --------------------------------------------------------------------------  //
//  This program is free software; you can redistribute it and/or               //
//  modify it under the terms of the GNU General Public License                 //
//  as published by the Free Software Foundation; either version 2              //
//  of the License, or (at your option) any later version.                      //
//                                                                              //
//  This program is distributed in the hope that it will be useful,             //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of              //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               //
//  GNU General Public License for more details.                                //
//                                                                              //
//  You should have received a copy of the GNU General Public License           //
//  along with this program; if not, write to the Free Software                 //
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. //
//  --------------------------------------------------------------------------  //

include '../../../include/cp_header.php';
if ( file_exists("../language/".$xoopsConfig['language']."/modinfo.php") ) {
	include_once "../language/".$xoopsConfig['language']."/modinfo.php";
} else {
	include_once "../language/english/modinfo.php";
}
if ( file_exists("../language/".$xoopsConfig['language']."/main.php") ) {
	include_once "../language/".$xoopsConfig['language']."/main.php";
} else {
	include_once "../language/english/main.php";
}
include_once XOOPS_ROOT_PATH.'/class/xoopstree.php';
include_once XOOPS_ROOT_PATH."/class/xoopslists.php";
$myts =& MyTextSanitizer::getInstance();

function default_admin_page()
{
    global $xoopsDB, $xoopsModule;
	xoops_cp_header();
	
	$mid = $xoopsModule -> getVar( 'mid' );
	$x_url = XOOPS_URL;
	$general = _PREFERENCES;

	echo "<h4>"._MD_XOONIPS_ADMIN."</h4>";
	
	echo"<table width='100%' border='0' cellspacing='1' class='outer'>";
	
	echo "<tr class=\"odd\"><td>";
	echo " - <a href='$x_url/modules/xoonips/admin/config_test.php'>" . _MI_XOONIPS_ADMENU1 . "</a>\n";
	echo "<br /><br />";
	echo " - <a href='$x_url/modules/xoonips/admin/useradmin.php'>"._MI_XOONIPS_ADMENU2."</a>";
	echo "<br /><br />";
	echo " - <a href='$x_url/modules/xoonips/admin/config.php'>"._MI_XOONIPS_ADMENU3."</a>";
	echo "<br /><br />";
	echo " - <a href='$x_url/modules/xoonips/admin/pickup.php'>"._MI_XOONIPS_ADMENU4."</a>";
	echo "<br /><br />";
	echo " - <a href='$x_url/modules/xoonips/admin/oaipmh.php'>"._MI_XOONIPS_ADMENU5."</a>";
	echo "<br /><br />";
	echo " - <a href='$x_url/modules/system/admin.php?fct=preferences&op=showmod&mod=$mid'>$general</a>\n";
	echo "</td></tr>";
	
	echo "</table>";


	xoops_cp_footer();
}

if(!isset($_POST['op'])) {
	$op = isset($_GET['op']) ? $_GET['op'] : 'main';
} else {
	$op = $_POST['op'];
}
switch ($op) {
default:
	default_admin_page();
	break;
}

?>

==> xoonips-3.24a.tar.gz: xoonips-3.24a/xoonips/admin/index.php <==
<?php
//  $Revision: 1.11 $                                                                  //
//  --------------------------------------------------------------------------  //
//  XooNIps Xoops modules for Neuroinformatics Platforms                        //
//  Copyright (C) 2005 RIKEN, Japan. All rights reserved.                       //
//  http://sourceforge.jp/projects/xoonips/                                     //
//  --------------------------------------------------------------------------  //
//  This program is free software; you can redistribute it and/or               //
//  modify it under the terms of the GNU General Public License                 //
//  as published by the Free Software Foundation; either version 2              //
//  of the License, or (at your option) any later version.                      //
//                                                                              //
//  This program is distributed in the hope that it will be useful,             //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of              //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               //
//  GNU General Public License for more details.                                //
//                                                                              //
//  You should have received a copy of the GNU General Public License           //
//  along with this program; if not, write to the Free Software                 //
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. //
//  --------------------------------------------------------------------------  //

include '../../../include/cp_header.php';
if ( file_exists("../language/".$xoopsConfig['language']."/modinfo.php") ) {
	include_once "../language/".$xoopsConfig['language']."/modinfo.php";
} else {
	include_once "../language/english/modinfo.php";
}
if ( file_exists("../language/".$xoopsConfig['language']."/main.php") ) {
	include_once "../language/".$xoopsConfig['language']."/main.php";
} else {
	include_once "../language/english/main.php";
}
include_once XOOPS_ROOT_PATH.'/class/xoopstree.php';
include_once XOOPS_ROOT_PATH."/class/xoopslists.php";
$myts =& MyTextSanitizer::getInstance();

function default_admin_page()
{
    global $xoopsDB, $xoopsModule;
	xoops_cp_header();
	
	$mid = $xoopsModule -> getVar( 'mid' );
	$x_url = XOOPS_URL;
	$general = _PREFERENCES;

	echo "<h4>"._MD_XOONIPS_ADMIN."</h4>";
	
	echo"<table width='100%' border='0' cellspacing='1' class='outer'>";
	
	echo "<tr class=\"odd\"><td>";
	echo " - <a href='$x_url/modules/xoonips/admin/useradmin.php'>"._MI_XOONIPS_ADMENU2."</a>";
	echo "<br /><br />";
	echo " - <a href='$x_url/modules/xoonips/admin/config.php'>"._MI_XOONIPS_ADMENU3."</a>";
	echo "<br /><br />";
	echo " - <a href='$x_url/modules/xoonips/admin/pickup.php'>"._MI_XOONIPS_ADMENU4."</a>";
	echo "<br /><br />";
	echo " - <a href='$x_url/modules/xoonips/admin/oaipmh.php'>"._MI_XOONIPS_ADMENU5."</a>";
	echo "<br /><br />";
	echo " - <a href='$x_url/modules/system/admin.php?fct=preferences&op=showmod&mod=$mid'>$general</a>\n";
	echo "<br /><br />";
	echo " - <a href='$x_url/modules/xoonips/admin/filesearch.php'>"._MI_XOONIPS_ADMENU6."</a>";
	echo "<br /><br />";
	echo " - <a href='$x_url/modules/xoonips/admin/posi_order.php'>"._MI_XOONIPS_ADMENU7."</a>";
	echo "<br /><br />";
	echo " - <a href='$x_url/modules/xoonips/admin/ranking.php'>"._MI_XOONIPS_ADMENU8."</a>";
	echo "<br /><br />";
	echo " - <a href='$x_url/modules/xoonips/admin/ranking_log.php'>"._MI_XOONIPS_ADMENU9."</a>";
	echo "<br /><br />";
	echo " - <a href='$x_url/modules/xoonips/admin/itemtype_order.php'>"._MI_XOONIPS_ADMENU10."</a>";
	echo "</td></tr>";
	
	echo "</table>";


	xoops_cp_footer();
}

if(!isset($_POST['op'])) {
	$op = isset($_GET['op']) ? $_GET['op'] : 'main';
} else {
	$op = $_POST['op'];
}
switch ($op) {
default:
	default_admin_page();
	break;
}

?>
